Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1214)

Unified Diff: net/url_request/url_fetcher_core.h

Issue 2599873002: Allow URLFetcher to be used from sequenced tasks. (Closed)
Patch Set: remove get() Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_fetcher.h ('k') | net/url_request/url_fetcher_core.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_fetcher_core.h
diff --git a/net/url_request/url_fetcher_core.h b/net/url_request/url_fetcher_core.h
index 704697a1352ee9c906ce3b561e4f2e1894bc06fb..570c0f8e4148bb9924dbf3afa8cd7daad3083330 100644
--- a/net/url_request/url_fetcher_core.h
+++ b/net/url_request/url_fetcher_core.h
@@ -27,6 +27,7 @@
#include "url/gurl.h"
namespace base {
+class SequencedTaskRunner;
class SingleThreadTaskRunner;
} // namespace base
@@ -216,10 +217,10 @@ class URLFetcherCore : public base::RefCountedThreadSafe<URLFetcherCore>,
// Notify Delegate about the progress of upload/download.
void InformDelegateUploadProgress();
- void InformDelegateUploadProgressInDelegateThread(int64_t current,
- int64_t total);
+ void InformDelegateUploadProgressInDelegateSequence(int64_t current,
+ int64_t total);
void InformDelegateDownloadProgress();
- void InformDelegateDownloadProgressInDelegateThread(
+ void InformDelegateDownloadProgressInDelegateSequence(
int64_t current,
int64_t total,
int64_t current_network_bytes);
@@ -233,8 +234,8 @@ class URLFetcherCore : public base::RefCountedThreadSafe<URLFetcherCore>,
URLFetcher::RequestType request_type_; // What type of request is this?
URLRequestStatus status_; // Status of the request
URLFetcherDelegate* delegate_; // Object to notify on completion
- // Task runner for the creating thread. Used to interact with the delegate.
- scoped_refptr<base::SingleThreadTaskRunner> delegate_task_runner_;
+ // Task runner for the creating sequence. Used to interact with the delegate.
+ const scoped_refptr<base::SequencedTaskRunner> delegate_task_runner_;
// Task runner for network operations.
scoped_refptr<base::SingleThreadTaskRunner> network_task_runner_;
// Task runner for upload file access.
« no previous file with comments | « net/url_request/url_fetcher.h ('k') | net/url_request/url_fetcher_core.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698